Function crs_bind::bindings::serial_enable [−][src]
pub unsafe extern "C" fn serial_enable(port: u8) -> i32
Enables generic serial on the given port.
\note This function must be called before any of the generic serial functions will work.
This function uses the following values of errno when an error state is reached: EINVAL - The given value is not within the range of V5 ports (1-21). EACCES - Another resource is currently trying to access the port.
\param port The V5 port number from 1-21
\return 1 if the operation was successful or PROS_ERR if the operation failed, setting errno.