Module crs_bind::io [−][src]
STDIO/STDERR macros.
Macros
| eprint | Macro for printing to the standard error. |
| eprintln | Macro for printing to the standard error, with a newline. |
Macro for printing to the standard output. | |
| println | Macro for printing to the standard output, with a newline. |