Function crs_bind::bindings::sem_create [−][src]
pub unsafe extern "C" fn sem_create(max_count: u32, init_count: u32) -> sem_t
Creates a counting sempahore.
See https://pros.cs.purdue.edu/v5/tutorials/multitasking.html#semaphores for details.
\param max_count The maximum count value that can be reached. \param init_count The initial count value assigned to the new semaphore.
\return A newly created semaphore. If an error occurred, NULL will be returned and errno can be checked for hints as to why sem_create failed.